pub trait CollectLifetimes {
// Required methods
fn collect_lifetimes<'a>(
self,
options: &Options,
lifetimes: &'a HashSet<Lifetime>,
) -> HashSet<&'a Lifetime>;
fn collect_lifetimes_cloned(
self,
options: &Options,
lifetimes: &HashSet<Lifetime>,
) -> HashSet<Lifetime>;
}Expand description
Searcher for finding lifetimes in an iterator.
This trait extends iterators, providing a way to turn a filtered list of fields or variants into a set of lifetimes.